======================
Django Evolution 0.6.2
======================

**Release date:** November 19, 2010


New Features
============

* Add compatibility with Django 1.3.

  Django 1.3 introduced a change to the ``Session.expire_date`` field's
  schema, setting ``db_index`` to ``True``. This caused Django Evolution to
  fail during evolution, with no way to provide an evolution file to work
  around the problem. Django Evolution now handles this by providing the
  evolution when running with Django 1.3 or higher.


Contributors
============

* Christian Hammond
